summaryrefslogtreecommitdiff
path: root/libgfortran/generated/eoshift1_4.c
diff options
context:
space:
mode:
Diffstat (limited to 'libgfortran/generated/eoshift1_4.c')
-rw-r--r--libgfortran/generated/eoshift1_4.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libgfortran/generated/eoshift1_4.c b/libgfortran/generated/eoshift1_4.c
index 81e85509820..bd5fabad311 100644
--- a/libgfortran/generated/eoshift1_4.c
+++ b/libgfortran/generated/eoshift1_4.c
@@ -105,8 +105,8 @@ eoshift1 (gfc_array_char * const restrict ret,
GFC_DIMENSION_SET(ret->dim[i], 0, ub, str);
}
- /* xmalloc allocates a single byte for zero size. */
- ret->base_addr = xmalloc (size * arraysize);
+ /* xmallocarray allocates a single byte for zero size. */
+ ret->base_addr = xmallocarray (arraysize, size);
}
else if (unlikely (compile_options.bounds_check))